@@ -1,6 +1,5 @@
-# This prevents gtk themes from interfering with Pango colors
+# This prevents gtk2 themes from interfering with Pango colors
 export GTK2_RC_FILES=/usr/share/themes/Default/gtk-2.0-key/gtkrc
-export GTK_THEME=Adwaita
 
 LOADED_STYLE="true"
 
@@ -24,47 +23,31 @@ fi
 #--image=gtk-dialog-question
 #--image=gtk-dialog-info
 
-yad_version=$(yad --version 2>/dev/null |  sed "s/[^0-9].*//")
-#echo "yad_version is " $yad_version
-
-BUTTON_OK="gtk-ok"
-BUTTON_CANCEL="gtk-cancel"
-BUTTON_NO="gtk-no"
-BUTTON_YES="gtk-yes"
-
-if [ $(($yad_version)) -gt 1 ]; then
-	BUTTON_OK="yad-ok"
-	BUTTON_CANCEL="yad-cancel"
-	BUTTON_NO="yad-no"
-	BUTTON_YES="yad-yes"
-fi
-
 YAD_DEVICE_OPTS="
     --width=680 --height=400
-    --button=$BUTTON_OK:0
-    --button=$BUTTON_CANCEL:1"
+    --button=gtk-ok:0
+    --button=gtk-cancel:1"
 
 YAD_YES_NO_OPTS="
-    --button=$BUTTON_YES:0
-    --button=$BUTTON_NO:1"
+    --button=gtk-yes:0
+    --button=gtk-no:1"
 
 YAD_ERROR_OPTS="
     --image=gtk-dialog-error
-    --button=$BUTTON_OK:0"
+    --button=gtk-ok:0"
 
 YAD_EXIT_OPTS="
-    --button=$BUTTON_OK:0"
+    --button=gtk-ok:0"
 
 YAD_INFO_OPTS="
-    --button=$BUTTON_OK:0"
+    --button=gtk-ok:0"
 
 YAD_BG_INFO_OPTS="
-    --button=$BUTTON_CANCEL"
+    --button=gtk-cancel"
 
 YAD_MULTI_OPTS="
-    --button=$BUTTON_OK:0
-    --button=$BUTTON_CANCEL:1"
-    
+    --button=gtk-ok:0
+    --button=gtk-cancel:1"
 
 set_color() {
 
